/*
 * This file is a part of PikoTools
 * and is distributed under the 2-Clause BSD licence.
 * Author: Tomasz Sowa <t.sowa@ttmath.org>
 */

/*
 * Copyright (c) 2021-2022, Tomasz Sowa
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include "inttostr.h"


namespace pt
{

std::string to_str(unsigned long long value, int base, size_t min_width)
{
	std::string res;
	Toa(value, res, false, base, min_width);

	return res;
}


std::string to_str(long long value, int base, size_t min_width)
{
	std::string res;
	Toa(value, res, false, base, min_width);

	return res;
}


std::string to_str(unsigned long value, int base, size_t min_width)
{
	return to_str(static_cast<unsigned long long>(value), base, min_width);
}


std::string to_str(long value, int base, size_t min_width)
{
	return to_str(static_cast<long long>(value), base, min_width);
}


std::string to_str(unsigned int value, int base, size_t min_width)
{
	return to_str(static_cast<unsigned long long>(value), base, min_width);
}


std::string to_str(int value, int base, size_t min_width)
{
	return to_str(static_cast<long long>(value), base, min_width);
}


std::string to_str(unsigned short value, int base, size_t min_width)
{
	return to_str(static_cast<unsigned long long>(value), base, min_width);
}


std::string to_str(short value, int base, size_t min_width)
{
	return to_str(static_cast<long long>(value), base, min_width);
}





std::wstring to_wstr(unsigned long long value, int base, size_t min_width)
{
	std::wstring res;
	Toa(value, res, false, base, min_width);

	return res;
}


std::wstring to_wstr(long long value, int base, size_t min_width)
{
	std::wstring res;
	Toa(value, res, false, base, min_width);

	return res;
}


std::wstring to_wstr(unsigned long value, int base, size_t min_width)
{
	return to_wstr(static_cast<unsigned long long>(value), base, min_width);
}


std::wstring to_wstr(long value, int base, size_t min_width)
{
	return to_wstr(static_cast<long long>(value), base, min_width);
}


std::wstring to_wstr(unsigned int value, int base, size_t min_width)
{
	return to_wstr(static_cast<unsigned long long>(value), base, min_width);
}


std::wstring to_wstr(int value, int base, size_t min_width)
{
	return to_wstr(static_cast<long long>(value), base, min_width);
}


std::wstring to_wstr(unsigned short value, int base, size_t min_width)
{
	return to_wstr(static_cast<unsigned long long>(value), base, min_width);
}


std::wstring to_wstr(short value, int base, size_t min_width)
{
	return to_wstr(static_cast<long long>(value), base, min_width);
}


}

