/*
 * This file is a part of PikoTools
 * and is distributed under the 2-Clause BSD licence.
 * Author: Tomasz Sowa <t.sowa@ttmath.org>
 */

/*
 * Copyright (c) 2021, Tomasz Sowa
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifndef headerfile_pikotools_src_csv_csvparser
#define headerfile_pikotools_src_csv_csvparser

#include <string>
#include <fstream>
#include "space/space.h"
#include "convert/baseparser.h"



namespace pt
{

/*
 *
 * https://datatracker.ietf.org/doc/html/rfc4180
 *
 */
class CSVParser : public BaseParser
{
public:

	CSVParser();

	enum Status
	{
		ok,
		cant_open_file,
	};


	Status parse_file(const char * file_name,         Space & out_space);
	Status parse_file(const std::string & file_name,  Space & out_space);
	Status parse_file(const wchar_t * file_name,      Space & out_space);
	Status parse_file(const std::wstring & file_name, Space & out_space);

	Status parse(const char * str,                    Space & out_space);
	Status parse(const std::string & str,             Space & out_space);
	Status parse(const wchar_t * str,                 Space & out_space);
	Status parse(const std::wstring & str,            Space & out_space);



protected:


	/*
		the last status of parsing, set by Parse() methods
	*/
	Status status;


	Space * space;



	void parse();
	void parse_row(Space & row_space);

	bool read_value_to(Space & row_space);
	bool read_quoted_value_to(std::wstring & value);
	bool read_non_quoted_value_to(std::wstring & value);


};

}

#endif
