/*
 * This file is a part of PikoTools
 * and is distributed under the 2-Clause BSD licence.
 * Author: Tomasz Sowa <t.sowa@ttmath.org>
 */

/*
 * Copyright (c) 2021, Tomasz Sowa
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifndef headerfile_pikotools_src_tests_test
#define headerfile_pikotools_src_tests_test

#include <iostream>
#include <cstring>



namespace pt
{
extern int test_counter;
extern const char * test_msg;
extern bool was_error;


void test_status(bool status);
void reset_test_counter();
void reset_test_counter(const char * msg);



template<typename type_t>
bool test(const char * test_msg, type_t provided, type_t expected)
{
	std::cout << "test " << test_counter << ": ";

	if( test_msg )
		std::cout << test_msg;

	bool status = provided == expected;
	test_status(status);
	test_counter += 1;

	return status;
}


template<typename type_t>
bool test(type_t provided, type_t expected)
{
	return test(test_msg, provided, expected);
}


template<>
bool test<const char*>(const char * test_msg, const char * provided, const char * expected);

template<>
bool test<const wchar_t*>(const char * test_msg, const wchar_t * provided, const wchar_t * expected);



}

#endif
